Package: fastVoteR
Title: Efficient Voting Methods for Committee Selection
Version: 0.0.3
Authors@R: c(
    person("John", "Zobolas", , "bblodfon@gmail.com", role = c("cre", "aut"),
           comment = c(ORCID = "0000-0002-3609-8674")),
    person("Anne-Marie", "George", role = "ctb",
           comment = c(ORCID = "0000-0001-9232-8211"))
  )
Description: A fast 'Rcpp'-based implementation of polynomially-computable
    voting theory methods for committee ranking and scoring. The package
    includes methods such as Approval Voting (AV), Satisfaction Approval
    Voting (SAV), sequential Proportional Approval Voting (PAV), and
    sequential Phragmen's Rule. Weighted variants of these methods are
    also provided, allowing for differential voter influence.
License: MIT + file LICENSE
URL: https://bblodfon.github.io/fastVoteR/
Imports: checkmate, Rcpp
Suggests: testthat (>= 3.0.0)
LinkingTo: Rcpp
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: yes
Packaged: 2026-05-15 15:17:20 UTC; john
Author: John Zobolas [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-3609-8674>),
  Anne-Marie George [ctb] (ORCID:
    <https://orcid.org/0000-0001-9232-8211>)
Maintainer: John Zobolas <bblodfon@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-15 20:20:13 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-05-15 22:32:08 UTC; unix
Archs: fastVoteR.so.dSYM
