# Generated by roxygen2: do not edit by hand

export(av)
export(rank_candidates)
export(sav)
export(seq_pav)
export(seq_phragmen)
import(checkmate)
importFrom(Rcpp,sourceCpp)
useDynLib(fastVoteR, .registration = TRUE)
