# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

av_rcpp <- function(voters, candidates, weights) {
    .Call(`_fastVoteR_av_rcpp`, voters, candidates, weights)
}

seq_pav_rcpp <- function(voters, candidates, weights, committee_size) {
    .Call(`_fastVoteR_seq_pav_rcpp`, voters, candidates, weights, committee_size)
}

seq_phragmen_rcpp <- function(voters, candidates, weights, committee_size) {
    .Call(`_fastVoteR_seq_phragmen_rcpp`, voters, candidates, weights, committee_size)
}

sav_rcpp <- function(voters, candidates, weights) {
    .Call(`_fastVoteR_sav_rcpp`, voters, candidates, weights)
}

